@@ -34,11 +34,6 @@ sub require_full {
         unless Panda::XS::Test->can('i8');
 }
 
-sub require_c11 {
-    plan skip_all => 'rebuild Makefile.pl adding CPP11X=1 to enable std::shared_ptr tests'
-        unless Panda::XS::Test->can('hold_mybase_ssp');
-}
-
 sub require_threads {
     plan skip_all => 'threaded perl required to run these tests'
         unless eval "use threads; use threads::shared; 1;";
@@ -86,4 +81,4 @@ sub require_threads {
     sub id { my $self = shift; return @_ ? $self->SUPER::id(@_) : ($self->SUPER::id() + 111) }
 }
 
-1;
\ No newline at end of file
+1;
