@@ -11,7 +11,7 @@ public:
 class MyChild : public MyBase {
 public:
     int val2;
-    MyChild (int arg1, int arg2) : val2(arg2), MyBase(arg1) {}
+    MyChild (int arg1, int arg2) : MyBase(arg1), val2(arg2) {}
     MyBase* clone () { return new MyChild(val, val2); }
     virtual ~MyChild () { dcnt++; }
 };
