@@ -28,7 +28,7 @@ class WrapperChild : public Wrapper {
 public:
     int xval2;
 
-    WrapperChild (WChild* arg) : xval2(0), Wrapper(arg) {}
+    WrapperChild (WChild* arg) : Wrapper(arg), xval2(0) {}
 
     virtual Wrapper* clone () {
         WrapperChild* cloned = new WrapperChild(static_cast<WChild*>(obj->clone()));
